@@ -3,6 +3,7 @@
 namespace Icinga\Module\Director\Forms;
 
 use gipfl\IcingaWeb2\Link;
+use Icinga\Module\Director\Auth\Permission;
 use Icinga\Module\Director\Web\Form\DirectorObjectForm;
 use Icinga\Module\Director\Objects\IcingaHost;
 use Icinga\Module\Director\Objects\IcingaService;
@@ -29,7 +30,13 @@ class IcingaAddServiceForm extends DirectorObjectForm
             );
         }
 
-        $this->addSingleImportElement();
+        $this->addSingleImportElement(true);
+
+        if (empty($this->enumServiceTemplates())) {
+            $this->setSubmitLabel(false);
+
+            return;
+        }
 
         if (! ($imports = $this->getSentOrObjectValue('imports'))) {
             $this->setSubmitLabel($this->translate('Next'));
@@ -82,7 +89,7 @@ class IcingaAddServiceForm extends DirectorObjectForm
                 if ($this->hasBeenSent()) {
                     $this->addError($this->translate('No service has been chosen'));
                 } else {
-                    if ($this->hasPermission('director/admin')) {
+                    if ($this->hasPermission(Permission::ADMIN)) {
                         $html = sprintf(
                             $this->translate('Please define a %s first'),
                             Link::create(
