@@ -2,7 +2,10 @@
 
 namespace Icinga\Module\Director\Forms;
 
+use Exception;
 use Icinga\Exception\AuthenticationException;
+use Icinga\Module\Director\Auth\Permission;
+use Icinga\Module\Director\Auth\Restriction;
 use Icinga\Module\Director\Repository\IcingaTemplateRepository;
 use Icinga\Module\Director\Restriction\HostgroupRestriction;
 use Icinga\Module\Director\Web\Form\DirectorObjectForm;
@@ -81,7 +84,13 @@ class IcingaHostForm extends DirectorObjectForm
             'class' => 'autosubmit',
         ]);
 
-        if ($this->getSentOrResolvedObjectValue('has_agent') === 'y') {
+        try {
+            $hasAgent = $this->getSentOrResolvedObjectValue('has_agent') === 'y';
+        } catch (Exception $e) {
+            $hasAgent = false;
+        }
+
+        if ($hasAgent) {
             $this->addBoolean('master_should_connect', [
                 'label'       => $this->translate('Establish connection'),
                 'description' => $this->translate(
@@ -97,6 +106,17 @@ class IcingaHostForm extends DirectorObjectForm
 
             $this->addHidden('command_endpoint_id', null);
             $this->setSentValue('command_endpoint_id', null);
+
+            $settings = $this->object->getConnection()->settings();
+            if ($settings->get('feature_custom_endpoint') === 'y' && ! $this->isTemplate()) {
+                $this->addElement('text', 'custom_endpoint_name', [
+                    'label'       => $this->translate('Custom Endpoint Name'),
+                    'description' => $this->translate(
+                        'Use a different name for the generated endpoint object than the host name'
+                        . ' and add a custom variable to allow services setting the correct command endpoint.'
+                    ),
+                ]);
+            }
         } else {
             if ($this->isTemplate()) {
                 $this->addElement('select', 'command_endpoint_id', [
@@ -123,6 +143,7 @@ class IcingaHostForm extends DirectorObjectForm
             'master_should_connect',
             'accept_config',
             'command_endpoint_id',
+            'custom_endpoint_name',
             'api_key',
         ];
         $this->addDisplayGroup($elements, 'clustering', [
@@ -150,7 +171,7 @@ class IcingaHostForm extends DirectorObjectForm
                 if ($this->hasBeenSent()) {
                     $this->addError($this->translate('No Host template has been chosen'));
                 } else {
-                    if ($this->hasPermission('director/admin')) {
+                    if ($this->hasPermission(Permission::ADMIN)) {
                         $html = sprintf(
                             $this->translate('Please define a %s first'),
                             Link::create(
@@ -195,8 +216,9 @@ class IcingaHostForm extends DirectorObjectForm
      */
     protected function addGroupsElement()
     {
-        if ($this->hasHostGroupRestriction()
-            && ! $this->getAuth()->hasPermission('director/groups-for-restricted-hosts')
+        if (
+            $this->hasHostGroupRestriction()
+            && ! $this->getAuth()->hasPermission(Permission::GROUPS_FOR_RESTRICTED_HOSTS)
         ) {
             return $this;
         }
@@ -250,15 +272,6 @@ class IcingaHostForm extends DirectorObjectForm
         return $this;
     }
 
-    protected function strikeGroupLinks(BaseHtmlElement $links)
-    {
-        /** @var BaseHtmlElement $link */
-        foreach ($links->getContent() as $link) {
-            $link->getAttributes()->add('style', 'text-decoration: strike');
-        }
-        $links->add('aha');
-    }
-
     protected function getInheritedGroups()
     {
         if ($this->hasObject()) {
@@ -283,9 +296,7 @@ class IcingaHostForm extends DirectorObjectForm
             );
         }
 
-        return Html::tag('span', [
-            'style' => 'line-height: 2.5em; padding-left: 0.5em'
-        ], $links);
+        return Html::tag('span', ['class' => 'host-group-links'], $links);
     }
 
     protected function getAppliedGroups()
@@ -299,7 +310,7 @@ class IcingaHostForm extends DirectorObjectForm
 
     protected function hasHostGroupRestriction()
     {
-        return $this->getAuth()->getRestrictions('director/filter/hostgroups');
+        return $this->getAuth()->getRestrictions(Restriction::FILTER_HOSTGROUPS);
     }
 
     /**
