@@ -41,12 +41,18 @@ class KickstartForm extends DirectorForm
             $this->addResourceConfigElements();
             $this->addResourceDisplayGroup();
 
-            if (!$this->config()->get('db', 'resource')
-                || ($this->config()->get('db', 'resource') !== $this->getResourceName())) {
+            if (
+                !$this->config()->get('db', 'resource')
+                || ($this->config()->get('db', 'resource') !== $this->getResourceName())
+            ) {
                 return;
             }
         }
 
+        if (!$this->hasBeenSent() && !$this->tryDbConnection()) {
+            return;
+        }
+
         if (!$this->migrations()->hasSchema()) {
             $this->addHtmlHint($this->translate(
                 'No database schema has been created yet'
@@ -71,7 +77,7 @@ class KickstartForm extends DirectorForm
             $hint = Html::sprintf(
                 $this->translate('Your database looks good, you are ready to %s'),
                 Link::create(
-                    'start working with the Icinga Director',
+                    $this->translate('start working with the Icinga Director'),
                     'director',
                     null,
                     ['data-base-target' => '_main']
@@ -194,35 +200,8 @@ class KickstartForm extends DirectorForm
             // Do not hinder the form from being stored
             return;
         }
-        if ($resourceName = $this->getResourceName()) {
-            $resourceConfig = ResourceFactory::getResourceConfig($resourceName);
-            if (! isset($resourceConfig->charset)
-                || ! in_array($resourceConfig->charset, array('utf8', 'utf8mb4', 'UTF8', 'UTF-8'))
-            ) {
-                if ($resource = $this->getElement('resource')) {
-                    $resource->addError('Please change the encoding for the director database to utf8');
-                } else {
-                    $this->addError('Please change the encoding for the director database to utf8');
-                }
-            }
 
-            $resource = $this->getResource();
-            $db = $resource->getDbAdapter();
-
-            try {
-                $db->fetchOne('SELECT 1');
-            } catch (Exception $e) {
-                $this->getElement('resource')
-                    ->addError('Could not connect to database: ' . $e->getMessage());
-
-                $hint = $this->translate(
-                    'Please make sure that your database exists and your user has'
-                    . ' been granted enough permissions'
-                );
-
-                $this->addHtmlHint($hint, array('name' => 'HINT_db_perms'));
-            }
-        }
+        $this->tryDbConnection();
     }
 
     /**
@@ -343,7 +322,7 @@ class KickstartForm extends DirectorForm
                 )
             );
             $this->addHtmlHint(
-                Html::tag('pre', null, $config),
+                Html::tag('pre', null, (string) $config),
                 array('name' => 'HINT_config_store')
             );
 
@@ -376,8 +355,10 @@ class KickstartForm extends DirectorForm
             }
         }
 
-        if ($this->getSubmitLabel() === $this->createDbLabel
-            || $this->getSubmitLabel() === $this->migrateDbLabel) {
+        if (
+            $this->getSubmitLabel() === $this->createDbLabel
+            || $this->getSubmitLabel() === $this->migrateDbLabel
+        ) {
             $this->migrations()->applyPendingMigrations();
             parent::onSuccess();
         }
@@ -466,4 +447,41 @@ class KickstartForm extends DirectorForm
 
         return $resources;
     }
+
+    protected function tryDbConnection()
+    {
+        if ($resourceName = $this->getResourceName()) {
+            $resourceConfig = ResourceFactory::getResourceConfig($resourceName);
+            if (
+                !isset($resourceConfig->charset)
+                || !in_array($resourceConfig->charset, array('utf8', 'utf8mb4', 'UTF8', 'UTF-8'))
+            ) {
+                if ($resource = $this->getElement('resource')) {
+                    $resource->addError('Please change the encoding for the director database to utf8');
+                } else {
+                    $this->addError('Please change the encoding for the director database to utf8');
+                }
+            }
+
+            $resource = $this->getResource();
+            $db = $resource->getDbAdapter();
+
+            try {
+                $db->fetchOne('SELECT 1');
+                return true;
+            } catch (Exception $e) {
+                $this->getElement('resource')
+                    ->addError('Could not connect to database: ' . $e->getMessage());
+
+                $hint = $this->translate(
+                    'Please make sure that your database exists and your user has'
+                    . ' been granted enough permissions'
+                );
+
+                $this->addHtmlHint($hint, array('name' => 'HINT_db_perms'));
+            }
+        }
+
+        return false;
+    }
 }
