@@ -11,7 +11,7 @@ use Iterator;
 
 class IcingaArguments implements Iterator, Countable, IcingaConfigRenderer
 {
-    const COMMENT_DSL_UNSUPPORTED = '/* Icinga 2 does not export DSL function bodies via API */';
+    public const COMMENT_DSL_UNSUPPORTED = '/* Icinga 2 does not export DSL function bodies via API */';
 
     /** @var IcingaCommandArgument[] */
     protected $storedArguments = [];
@@ -155,7 +155,9 @@ class IcingaArguments implements Iterator, Countable, IcingaConfigRenderer
             if (property_exists($value, 'type')) {
                 // argument is directly set as function, no further properties
                 if ($value->type === 'Function') {
-                    $attrs['argument_value'] = self::COMMENT_DSL_UNSUPPORTED;
+                    $attrs['argument_value'] = property_exists($value, 'body')
+                        ? $value->body
+                        : self::COMMENT_DSL_UNSUPPORTED;
                     $attrs['argument_format'] = 'expression';
                 }
             } elseif (property_exists($value, 'value')) {
@@ -214,10 +216,12 @@ class IcingaArguments implements Iterator, Countable, IcingaConfigRenderer
             $this->set($arg, $val);
         }
 
-        foreach (array_diff(
-            array_keys($this->arguments),
-            array_keys($arguments)
-        ) as $arg) {
+        foreach (
+            array_diff(
+                array_keys($this->arguments),
+                array_keys($arguments)
+            ) as $arg
+        ) {
             if ($this->arguments[$arg]->hasBeenLoadedFromDb()) {
                 $this->arguments[$arg]->markForRemoval();
                 $this->modified = true;
@@ -296,6 +300,7 @@ class IcingaArguments implements Iterator, Countable, IcingaConfigRenderer
         $this->arguments = IcingaCommandArgument::loadAll($connection, $query, 'argument_name');
         $this->cloneStored();
         $this->refreshIndex();
+        $this->modified = false;
 
         return $this;
     }
@@ -360,6 +365,7 @@ class IcingaArguments implements Iterator, Countable, IcingaConfigRenderer
         }
         $this->refreshIndex();
         $this->cloneStored();
+        $this->modified = false;
     }
 
     /**
@@ -393,7 +399,9 @@ class IcingaArguments implements Iterator, Countable, IcingaConfigRenderer
             unset($this->arguments[$key]);
         }
 
+        $this->refreshIndex();
         $this->cloneStored();
+        $this->modified = false;
 
         return $this;
     }
