@@ -3,7 +3,8 @@
 namespace Icinga\Module\Director\PropertyModifier;
 
 use Icinga\Module\Director\Hook\PropertyModifierHook;
-use Icinga\Module\Director\Web\Form\QuickForm;
+
+use function iconv;
 
 class PropertyModifierFromLatin1 extends PropertyModifierHook
 {
@@ -14,6 +15,10 @@ class PropertyModifierFromLatin1 extends PropertyModifierHook
 
     public function transform($value)
     {
-        return utf8_encode($value);
+        if ($value === null) {
+            return null;
+        }
+
+        return iconv('ISO-8859-15', 'UTF-8', $value);
     }
 }
